@@ -7,7 +7,7 @@ import shutil
 import sys
 import textwrap
 
-from . import helpers
+from . import crypto, helpers
 
 
 class PasswordPromptAction(argparse.Action):
@@ -113,6 +113,9 @@ def get_parser():
         help="the skill's secret",
         prompt='Enter skill secret: ',
     )
+    invoke_parser.add_argument(
+        '-k', '--key-file', help="the path to the skill's public key file on disk", required=True
+    )
     invoke_parser.add_argument(
         '-U',
         '--url',
@@ -137,6 +140,9 @@ def get_parser():
         help="the skill's secret",
         prompt='Enter skill secret: ',
     )
+    check_parser.add_argument(
+        '-k', '--key-file', help="the path to the skill's public key file on disk", required=True
+    )
     check_parser.add_argument(
         '-U',
         '--url',
@@ -178,7 +184,9 @@ def new_skill(skill_name: str, secret: str, password=None):
     )
 
 
-def invoke_skill(secret, url, context=None, frame=None):
+def invoke_skill(secret, key_file, url, context=None, frame=None):
+    public_key = crypto.load_public_key_from_file(key_file)
+
     history = []
     first = True
     while True:
@@ -187,13 +195,14 @@ def invoke_skill(secret, url, context=None, frame=None):
             first = False
             text = input(f'{prompt}>>> ')
             res = helpers.make_request(
-                secret, text, context=context, frame=frame, history=history, url=url
+                secret, public_key, text, context=context, frame=frame, history=history, url=url
             )
             directives = res.get('directives')
             context = res.get('context')
             frame = res.get('frame')
             history = res.get('history', [])
-        except Exception:  # pylint: disable=broad-except
+        except Exception as exc:  # pylint: disable=broad-except
+            print(exc)
             print(f'Failed to invoke skill at {url}')
             return
         except KeyboardInterrupt:
@@ -204,8 +213,10 @@ def invoke_skill(secret, url, context=None, frame=None):
         pprint.pprint(directives, indent=2, width=width)
 
 
-def check_skill(secret, url):
-    res = helpers.make_health_check(secret, url)
+def check_skill(secret, key_file, url):
+    public_key = crypto.load_public_key_from_file(key_file)
+
+    res = helpers.make_health_check(secret, public_key, url)
     print(res)
 
 
@@ -233,7 +244,7 @@ def main():
 
         context = parse_json_argument('context', args.context) if args.context else None
         frame = parse_json_argument('frame', args.frame) if args.frame else None
-        invoke_skill(args.secret, url=args.url, context=context, frame=frame)
+        invoke_skill(args.secret, args.key_file, url=args.url, context=context, frame=frame)
         return
 
     if args.command == 'check':
@@ -241,7 +252,7 @@ def main():
             # reparse with added '-s'
             # Note: for some reason we have to pop off the first arg when reparsing
             args = parser.parse_args(args=sys.argv[1:] + ['-s'])
-        check_skill(args.secret, url=args.url)
+        check_skill(args.secret, args.key_file, url=args.url)
         return
 
     parser.print_help()
