@@ -10,10 +10,18 @@ class SkillApplication(Application):
     SkillApplication extends MindMeld application with the appropriate encryption protocols.
     """
 
-    def __init__(self, import_name, *, secret, responder_class=SkillResponder, **kwargs):
+    def __init__(
+            self,
+            import_name,
+            *,
+            secret,
+            private_key,
+            responder_class=SkillResponder,
+            **kwargs):
 
         super().__init__(import_name, responder_class=responder_class, **kwargs)
         self.secret = secret
+        self.private_key = private_key
 
     def introduce(self, handler=None):
         """Decorator for skill introduction states. If a skill is
@@ -34,7 +42,7 @@ class SkillApplication(Application):
 
     def lazy_init(self, nlp=None):
         Application.lazy_init(self, nlp)
-        self._server = create_skill_server(self.app_manager, self.secret)
+        self._server = create_skill_server(self.app_manager, self.secret, self.private_key)
 
     @property
     def web_app(self) -> Flask:
